<?php

/*********************************************************************

 Comic Viewer Ver 0.01a (2012/11/16)

*********************************************************************/

/********* ライセンス ************************************************

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

 @Link http://www.php-labo.net/
 @Copyright(C) 2007-2012 PHP Labo
 @Author Knight <info at php-labo dot net>

*********************************************************************/

/********* 設定項目 *************************************************/

//漫画データ格納ディレクトリのURL
define('DATA_DIR', 'data/');

/********* パラメーター取得 *****************************************/

if (empty($_GET['data']) or !preg_match('/^[\w\-]+$/', $_GET['data'])) {
	exit('error');
}

if (isset($_GET['navigation']) and $_GET['navigation'] == 'off') {
	$_GET['navigation'] = 'off';
} else {
	$_GET['navigation'] = 'on';
}

if (isset($_GET['columns']) and $_GET['columns'] == 1) {
	$_GET['columns'] = 1;
} else {
	$_GET['columns'] = 2;
}

if (isset($_GET['devide']) and $_GET['devide'] == 'on') {
	$_GET['devide'] = 'on';
} else {
	$_GET['devide'] = 'off';
}

if (isset($_GET['direction']) and $_GET['direction'] == 'ltr') {
	$_GET['direction'] = 'ltr';
} else {
	$_GET['direction'] = 'rtl';
}

if (isset($_GET['page'])) {
	$_GET['page'] = intval($_GET['page']);
} else {
	$_GET['page'] = 0;
}

/********* 画像取得 *************************************************/

$files = array();

if ($dir = scandir(DATA_DIR . $_GET['data'] . '/')) {
	foreach ($dir as $entry) {
		if (is_file(DATA_DIR . $_GET['data'] . '/' . $entry) and preg_match('/^[\d]+\.(gif|jpeg|jpg|jpe|png)$/i', $entry)) {
			$files[] = $entry;
		}
	}
} else {
	exit('画像格納ディレクトリを開けません。');
}

if (sort($files, SORT_NUMERIC) == false) {
	exit('画像をソートできません。');
}

if (preg_match('/\.(gif|jpeg|jpg|jpe|png)$/i', $files[0], $matches)) {
	$file_ext = $matches[1];
} else {
	exit('表示できる画像はGIF、Jpeg、PNGのみです。');
}

list($file_width, $file_height) = getimagesize(DATA_DIR . $_GET['data'] . '/' . $files[0]);

$first = intval($files[0]);
$last  = intval($files[count($files) - 1]);

/********* ページ出力 ***********************************************/

?>
<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8" />
		<title>comic</title>
		<link rel="stylesheet" href="css/common.css" />
		<style>
		html, body {
			height: 100%;
			margin: 0;
			padding: 0;
		}

		header {
			display: none;
		}

		nav {
			z-index: 1;
			position: fixed;
			clear: both;
			bottom: 10px;
			left: 10px;
		}
		nav ul {
			float: left;
			margin: 0 10px 0 0;
			padding: 0;
			border-right: 1px solid #222222;
		}
		nav ul li {
			display: inline;
			list-style: none;
			margin-right: 10px;
		}
		<?php if ($_GET['navigation'] == 'off') : ?>
		nav {
			display: none;
		}
		<?php endif ?>

		div#comic {
			height: 100%;
			text-align: center;
		}
		div#comic div.comic {
			overflow-x: auto;
			overflow-y: hidden;
			direction: <?php echo $_GET['direction'] ?>;
			width: 100%;
			<?php if ($_GET['devide'] == 'off') : ?>
			height: 100%;
			min-height: <?php echo $file_height ?>px;
			<?php endif ?>
			margin: 0;
			padding: 10px 0 30px;
			white-space: nowrap;
		}
		div#comic div.comic p {
			margin: 0;
			padding: 10px 0 0 0;
			display: inline;
		}
		div#comic div.comic p a img {
			border: 1px solid #AAAAAA;
		}

		footer {
			z-index: 1;
			position: fixed;
			clear: both;
			bottom: 10px;
			right: 10px;
		}
		</style>
		<script src="js/jquery.js"></script>
		<?php if ($_GET['devide'] == 'off') : ?>
		<script>
		$(document).ready(function() {
			var margin = 10;

			var matches = null;
			var first   = 0;
			var last    = 0;

			matches = $('a#first').attr('href').match(/#page-(\d+)/);
			if (matches && matches[1]) {
				first = parseInt(matches[1]);
			}

			matches = $('a#last').attr('href').match(/#page-(\d+)/);
			if (matches && matches[1]) {
				last = parseInt(matches[1]);
			}

			$('#status').html('全<em>' + (last - 1) + '</em>ページ');

			$('nav a, div#comic a').click(function() {
				var page = 0;

				matches = $(this).attr('href').match(/#page-(\d+)/);
				if (matches && matches[1]) {
					page = parseInt(matches[1]);
				}

				if (page < first) {
					return false;
				}
				if (page > last) {
					return false;
				}

				var previous = page - <?php echo $_GET['columns'] ?>;
				var next     = page + <?php echo $_GET['columns'] ?>;

				if (previous < first) {
					previous = first;
				} else if (page == last) {
					previous = last - 2;
				}
				if (next > last) {
					next = last;
				} else if (page == first) {
					next = first + 1;
				}

				$('a#previous').attr('href', '#page-' + previous);
				$('a#next').attr('href', '#page-' + next);

				$('html, body').animate({
					scrollTop: $('#page-' + page).offset().top - margin
				}, 0);

				if (page != first && page != last) {
					$('#status').html('全<em>' + (last - 1) + '</em>ページ / <em>' + page + '</em>ページ目を表示');
				} else {
					$('#status').html('全<em>' + (last - 1) + '</em>ページ');
				}

				return false;
			});
		});
		</script>
		<?php endif ?>
	</head>
	<body>
		<header>
			<h1>comic</h1>
		</header>
		<?php if ($_GET['devide'] == 'off') : ?>
		<nav>
			<ul>
				<li><a href="#page-<?php echo $first ?>" id="first">表紙</a></li>
				<li><a href="#page-<?php echo $first ?>" id="previous">前のページ</a></li>
				<li><a href="#page-<?php echo $first + 1 ?>" id="next">次のページ</a></li>
				<li><a href="#page-<?php echo $last ?>" id="last">裏表紙</a></li>
			</ul>
			<ul>
				<li><a href="#page-<?php echo $first ?>">表紙</a></li>
				<?php

					if ($_GET['columns'] == 1) {
						for ($i = $first; $i <= $last; $i++) {
							if ($i == $first or $i == $last) {
								continue;
							}

							echo "<li><a href=\"#page-" . $i . "\">" . $i . "</a></li>\n";
						}
					} else {
						for ($i = $first; $i <= $last; $i++) {
							if ($i % 2 == 0 or $i == $first or $i == $last) {
								continue;
							}

							echo "<li><a href=\"#page-" . $i . "\">" . $i . "-" . ($i + 1) . "</a></li>\n";
						}
					}

				?>
				<li><a href="#page-<?php echo $last ?>">裏表紙</a></li>
			</ul>
			<ul>
				<li id="status">-</li>
			</ul>
		</nav>
		<div id="comic">
			<?php

				if ($_GET['columns'] == 1) {
					for ($i = $first; $i <= $last; $i++) {
						if ($i == $last) {
							$link = '#page-' . $first;
						} else {
							$link = '#page-' . ($i + 1);
						}

						echo "<div class=\"comic\">";
						echo "<p><a href=\"" . $link . "\"><img src=\"" . DATA_DIR . $_GET['data'] . '/' . $i . '.' . $file_ext . "\" alt=\"" . $i . "\" width=\"" . $file_width . "\" height=\"" . $file_height . "\" id=\"page-" . $i . "\" /></a></p>";
						echo "</div>";
					}
				} else {
					for ($i = $first; $i <= $last; $i++) {
						if ($i % 2 == 0) {
							$link = '#page-' . ($i + 1);
						} else {
							$link = '#page-' . ($i - 1);
						}

						if ($i % 2 != 0 or $i == $first) {
							echo "<div class=\"comic\">";
						}

						echo "<p><a href=\"" . $link . "\"><img src=\"" . DATA_DIR . $_GET['data'] . '/' . $i . '.' . $file_ext . "\" alt=\"" . $i . "\" width=\"" . $file_width . "\" height=\"" . $file_height . "\" id=\"page-" . $i . "\" /></a></p>";

						if ($i % 2 == 0 or $i == $last) {
							echo "</div>";
						}
					}
				}

			?>
		</div>
		<?php else : ?>
		<header>
			<h1>comic</h1>
		</header>
		<nav>
			<ul>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $first ?>" id="first">表紙</a></li>
				<?php

				$previous = $_GET['page'] - $_GET['columns'];
				$next     = $_GET['page'] + $_GET['columns'];

				if ($previous < $first) {
					$previous = $first;
				} elseif ($_GET['page'] == $last) {
					$previous = $last - 2;
				}
				if ($next > $last) {
					$next = $last;
				} elseif ($_GET['page'] == $first) {
					$next = $first + 1;
				}

				?>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $previous ?>" id="previous">前のページ</a></li>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $next ?>" id="next">次のページ</a></li>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $last ?>" id="last">裏表紙</a></li>
			</ul>
			<ul>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $first ?>">表紙</a></li>
				<?php

					if ($_GET['columns'] == 1) {
						for ($i = $first; $i <= $last; $i++) {
							if ($i == $first or $i == $last) {
								continue;
							}

							echo "<li><a href=\"?data=" . $_GET['data'] . "&amp;devide=" . $_GET['devide'] . "&amp;columns=" . $_GET['columns'] . "&amp;page=" . $i . "\">" . $i . "</a></li>\n";
						}
					} else {
						for ($i = $first; $i <= $last; $i++) {
							if ($i % 2 == 0 or $i == $first or $i == $last) {
								continue;
							}

							echo "<li><a href=\"?data=" . $_GET['data'] . "&amp;devide=" . $_GET['devide'] . "&amp;columns=" . $_GET['columns'] . "&amp;page=" . $i . "\">" . $i . "-" . ($i + 1) . "</a></li>\n";
						}
					}

				?>
				<li><a href="?data=<?php echo $_GET['data'] ?>&amp;devide=<?php echo $_GET['devide'] ?>&amp;columns=<?php echo $_GET['columns'] ?>&amp;page=<?php echo $last ?>">裏表紙</a></li>
			</ul>
			<ul>
				<?php

				if ($_GET['page'] != $first and $_GET['page'] != $last) {
					echo "<li id=\"status\">全<em>" . ($last - 1) . "</em>ページ / <em>" . $_GET['page'] . "</em>ページ目を表示</li>\n";
				} else {
					echo "<li id=\"status\">全<em>" . ($last - 1) . "</em>ページ</li>\n";
				}

				?>
			</ul>
		</nav>
		<div id="comic">
			<?php

				if ($_GET['columns'] == 1) {
					for ($i = $first; $i <= $last; $i++) {
						if ($i != $_GET['page']) {
							continue;
						}

						if ($i == $last) {
							$link = '?data=' . $_GET['data'] . '&amp;devide=' . $_GET['devide'] . '&amp;columns=' . $_GET['columns'] . '&amp;page=' . $first;
						} else {
							$link = '?data=' . $_GET['data'] . '&amp;devide=' . $_GET['devide'] . '&amp;columns=' . $_GET['columns'] . '&amp;page=' . ($i + 1);
						}

						echo "<div class=\"comic\">";
						echo "<p><a href=\"" . $link . "\"><img src=\"" . DATA_DIR . $_GET['data'] . '/' . $i . '.' . $file_ext . "\" alt=\"" . $i . "\" width=\"" . $file_width . "\" height=\"" . $file_height . "\" /></a></p>";
						echo "</div>";
					}
				} else {
					for ($i = $first; $i <= $last; $i++) {
						if ($_GET['page'] == $first or $_GET['page'] == $last) {
							if ($i != $_GET['page']) {
								continue;
							}
						} else {
							if ($i != $_GET['page'] and $i != $_GET['page'] + 1) {
								continue;
							}
						}

						if ($i % 2 == 0) {
							$link = '?data=' . $_GET['data'] . '&amp;devide=' . $_GET['devide'] . '&amp;columns=' . $_GET['columns'] . '&amp;page=' . (($i + 1 > $last) ? $last : $i + 1);
						} else {
							$link = '?data=' . $_GET['data'] . '&amp;devide=' . $_GET['devide'] . '&amp;columns=' . $_GET['columns'] . '&amp;page=' . (($i - 2 < $first) ? $first : $i - 2);
						}

						if ($i % 2 != 0 or $i == $first) {
							echo "<div class=\"comic\">";
						}

						echo "<p><a href=\"" . $link . "\"><img src=\"" . DATA_DIR . $_GET['data'] . '/' . $i . '.' . $file_ext . "\" alt=\"" . $i . "\" width=\"" . $file_width . "\" height=\"" . $file_height . "\" /></a></p>";

						if ($i % 2 == 0 or $i == $last) {
							echo "</div>";
						}
					}
				}

			?>
		</div>
		<?php endif ?>
		<footer>
			<address><a href="http://www.php-labo.net/">Comic Viewer</a></address>
		</footer>
	</body>
</html>
